require(corHMM)
require(geiger)
require(ape)

##read in multiphylo

tree<-read.nexus('multiphyl.uvpat.nex')

##drop tips that lack human-vis pattern data

droptree<-lapply(tree, drop.tip, tip=c('P_adscharica', 'P_algida','P_anachoretica', 'P_anatolica', 'P_argyroloma', 'P_articulata', 'P_aucheriana', 'P_cappadocica', 'P_carduchorum', 'P_elvendiensis', 'P_flabellata', 'P_kotschyana', 'P_meyeri'))

class(droptree)='multiPhylo'

##read in species and phenotypic data for all taxa

dat<-read.table(pip('pbpaste'), header=TRUE) 


##read in species and phenotypic data for all taxa

dat.sub<-read.table(pip('pbpaste'), header=TRUE) 



##create data frames and matrices for the dataset of UV pattern and the subsetted data with species that have Petal Size, Vis and UV pattern.

attach(dat)

uvpat.dat<-data.frame(Tip, UVPatQuant)

uvpat.mat<-as.matrix(uvpat.dat)

attach(dat.sub)

vispat.dat<-data.frame(Tip, VisPatQuant)

vispat.mat<-as.matrix(vispat.dat)

##corHMM on multiphylo for UV and human-visible pattern. Each takes up to 2 days on a standard processor.


corhmm.uvpat.1rate<-lapply(tree, corHMM, data=uvpat.mat, rate.cat=1, nstarts=10)

corhmm.uvpat.2rate<-lapply(tree, corHMM, data=uvpat.mat, rate.cat=2, nstarts=10)

corhmm.uvpat.3rate<-lapply(tree, corHMM, data=uvpat.mat, rate.cat=3, nstarts=10)

corhmm.vispat.1rate<-lapply(droptree, corHMM, data=vispat.mat, rate.cat=1, nstarts=5)

corhmm.vispat.2rate<-lapply(droptree, corHMM, data=vispat.mat, rate.cat=2, nstarts=5)

corhmm.vispat.3rate<-lapply(droptree, corHMM, data=vispat.mat, rate.cat=3, nstarts=5)


##Pagel's test for correlated evolution between UV and human-visible petal pattern

attach(dat.sub)

cordisc.dat<-data.frame(Tip, UVPatQuant, VisPatQuant)

cordisc.pattern<-lapply(droptree, corDISC, data= cordisc.dat, ntraits=2) 


##Generalized estimating equation testing the effect of flower size on evolution of petal pattern

attach(dat)

uvpat.dat<-data.frame(Tip, UVPatQuant, PetArea)


gee.uvpat<-list()
for(i in 1:length(tree))
{
gee.uvpat[[i]]<-compar.gee(UVPatQuant ~ log(PetArea), data=uvpat.dat, family='binomial',phy=compute.brlen(tree[[i]],1))
}


attach(dat.sub)

vispat.dat<-data.frame(Tip, VisPatQuant, PetArea)


gee.vispat<-list()
for(i in 1:length(droptree))
{tryCatch({
gee.vispat[[i]]<-compar.gee(VisPatQuant ~ log(PetArea), data=vispat.dat, family='binomial',phy=compute.brlen(droptree[[i]],1))
},error=function(e){})
}






